OC.L10N.register(
    "core",
    {
    "Please select a file." : "Будь ласка, виберіть файл.",
    "File is too big" : "Файл занадто великий",
    "The selected file is not an image." : "Вибраний файл не є зображенням.",
    "The selected file cannot be read." : "Неможливо прочитати вибраний файл.",
    "The file was uploaded" : "Файл завантажено",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір завантаженого файлу перевищує директиву MAX_FILE_SIZE, зазначену у HTML-формі",
    "The file was only partially uploaded" : "Файл завантажено частково",
    "No file was uploaded" : "Не завантажено жодного файлу",
    "Missing a temporary folder" : "Відсутній каталог тимчасових файлів",
    "Could not write file to disk" : "Неможливо записати файл на диск",
    "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
    "Invalid file provided" : "Надано помилковий файл",
    "No image or file provided" : "Не надано зображення або файл",
    "Unknown filetype" : "Невідомий тип файлу",
    "An error occurred. Please contact your admin." : "Виникла помилка. Будь ласка, зв'яжіться з вашим адміністратором.",
    "Invalid image" : "Невірне зображення",
    "No temporary profile picture available, try again" : "Тимчасове зображення профілю недоступне, спробуйте ще раз",
    "No crop data provided" : "Відсутня інформація щодо кадрування",
    "No valid crop data provided" : "Не вказані коректні дані про кадрування",
    "Crop is not square" : "Кадр не є квадратним",
    "State token does not match" : "Токен стану не збігається",
    "Invalid app password" : "Неправильний пароль застосунку",
    "Could not complete login" : "Не вдалося увійти",
    "State token missing" : "Відсутній токен стану.",
    "Your login token is invalid or has expired" : "Ваш токен для входу неправильний або термін його дії вичерпано",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Цей випуск спільноти Nextcloud не підтримується, а push-сповіщення обмежені.",
    "Login" : "Вхід",
    "Unsupported email length (>255)" : "Довжина адреси ел.пошти не підтримується (більше 255 символів)",
    "Password reset is disabled" : "Відновлення пароля заборонено",
    "Could not reset password because the token is expired" : "Не вдалося скинути пароль, оскільки термін дії токена минув",
    "Could not reset password because the token is invalid" : "Не вдалося скинути пароль, оскільки токен не дійсний",
    "Password is too long. Maximum allowed length is 469 characters." : "Пароль є задовгим. Максимально дозволена довжина складає 469 символів.",
    "%s password reset" : "%s відновлення пароля",
    "Password reset" : "Відновлення пароля",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Щоби відновити ваш пароль, клацніть кнопку нижче. Якщо ви не здійснювали запиту на відновлення пароля, проігноруйте цей лист.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Перейдіть за посиланням для відновлення вашого пароля. Якщо ви не збираєтеся змінювати пароль, то просто проігноруйте цей лист.",
    "Reset your password" : "Відновити пароль",
    "The given provider is not available" : "Вибраний постачальний не доступний",
    "Task not found" : "Завдання не знайдено",
    "Internal error" : "Внутрішня помилка",
    "Not found" : "Не знайдено",
    "Bad request" : "Хибний запит",
    "Requested task type does not exist" : "Запитаний вид завдання відсутній",
    "Necessary language model provider is not available" : "Постачальний потрібної мовної моделі недоступний",
    "No text to image provider is available" : "Відсутній постачальник конвертування тексту у зображення",
    "Image not found" : "Зображення відсутнє",
    "No translation provider available" : "Постачальник послуг перекладу недоступний",
    "Could not detect language" : "Не вдалося визначити мову",
    "Unable to translate" : "Не вдалося перекласти",
    "Nextcloud Server" : "Сервер Nextcloud",
    "Some of your link shares have been removed" : "Окремі посилання на спільні елементи було вилучено",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Через ваду з безпекою ми вимушені були вилучити деякі ваші спільні посилання. Будь ласка, перегляньте цю докладну інформацію.",
    "The account limit of this instance is reached." : "Досягнути обмеження на кількість облікових записів цього примірника хмари.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Зазначте ваш ключ підписки у застосунку підтримки, щоб збільшити кількість дозволених облікових записів. Після цього ви отримаєте всі додаткові переваги, які надає Nextcloud для бізнесу. Ми рекомендуємо це зробити для комерційних користувачів.",
    "Learn more ↗" : "Дізнайтеся більше ↗",
    "Preparing update" : "Підготовка оновлення",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Крок у відновленні:",
    "Repair info:" : "Інформація про відновлення:",
    "Repair warning:" : "Застереження щодо відновлення:",
    "Repair error:" : "Помилка під час відновлення:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Будь ласка, скористайтеся оновленням через командний рядок, оскільки оновлення через бравзер вимкнено у файлі налаштувань config.php.",
    "Turned on maintenance mode" : "Активовано режим технічного обслуговування",
    "Turned off maintenance mode" : "Вимкнено режим технічного обслуговування",
    "Maintenance mode is kept active" : "Режим обслуговування залишається активним",
    "Updating database schema" : "Оновлення схеми бази даних",
    "Updated database" : "Базу даних оновлено",
    "Update app \"%s\" from App Store" : "Оновіть застосунок \"%s\" з App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Перевіряю, чи схема бази даних для %s може бути оновлена (це може зайняти багато часу, залежно від розмірів бази даних)",
    "Updated \"%1$s\" to %2$s" : "Оновлено з \"%1$s\" до %2$s",
    "Set log level to debug" : "Встановити рівень деталізації журналу у налагодження",
    "Reset log level" : "Скинути налаштування детальності журналу",
    "Starting code integrity check" : "Початок перевірки цілісності коду",
    "Finished code integrity check" : "Завершено перевірку цілісності коду",
    "%s (incompatible)" : "%s (несумісне)",
    "The following apps have been disabled: %s" : "Ці застосунки було вимкнено: %s",
    "Already up to date" : "Вже актуально",
    "Error occurred while checking server setup" : "При перевірці налаштувань серверу сталася помилка",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Додаткову інформацію див. у {linkstart}документації ↗{linkend}.",
    "unknown text" : "невідомий текст",
    "Hello world!" : "Привіт, світе!",
    "sunny" : "сонячно",
    "Hello {name}, the weather is {weather}" : "Привіт {name}, погода {weather} ",
    "Hello {name}" : "Привіт {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Це ваші результати пошуку<script>alert(1)</script></strong>",
    "new" : "новий",
    "_download %n file_::_download %n files_" : ["звантаження %n файлу","звантаження %n файлів","звантаження %n файлів","звантаження %n файлів"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Відбувається оновлення. Не залишайте цю сторінку, це може перервати процес у деяких середовищах.",
    "Update to {version}" : "Оновлення до {version}",
    "An error occurred." : "Виникла помилка.",
    "Please reload the page." : "Будь ласка, перезавантажте сторінку.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Оновлення не вдалося. За інформацією <a href=\"{url}\">зверніться до повідомлення на форумі</a>, що описує цю проблему.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Оновлення не вдалося. Будь ласка, повідомте про це питання в <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">спільноту Nextcloud</a>.",
    "Continue to {productName}" : "Перейти до {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Оновлення пройшло успішно. Переспрямування на {productName} за %n секунду.","Оновлення пройшло успішно. Переспрямування до {productName} за лічені %n секунди.","Оновлення пройшло успішно. Переспрямування до {productName} за лічені %n секунди.","Оновлення пройшло успішно. Переспрямування до {productName} за лічені %n секунди."],
    "Applications menu" : "Меню застосунків",
    "Apps" : "Застосунки",
    "More apps" : "Більше застосунків",
    "_{count} notification_::_{count} notifications_" : ["{count} сповіщень","{count} сповіщень","{count} сповіщень","{count} сповіщень"],
    "No" : "Ні",
    "Yes" : "Так",
    "The remote URL must include the user." : "Віддалена адреса повинна містити в собі імʼя користувача.",
    "Invalid remote URL." : "Недійсна віддалена адреса.",
    "Failed to add the public link to your Nextcloud" : "Не вдалося додати загальнодоступне посилання до вашого Nextcloud",
    "Federated user" : "Обʼєднаний користувач",
    "user@your-nextcloud.org" : "користувач@ваш-nextcloud.org",
    "Create share" : "Передати у публічний доступ",
    "Direct link copied to clipboard" : "Посилання прямого доступу скопійовано в буфер обміну",
    "Please copy the link manually:" : "Будь ласка, скопіюйте посилання вручну:",
    "Custom date range" : "Власний вибір проміжку",
    "Pick start date" : "Виберіть початкову дату",
    "Pick end date" : "Виберіть кінцеву дату",
    "Search in date range" : "Шукати в часовому проміжку",
    "Search in current app" : "Шукати в поточному застосунку",
    "Clear search" : "Очистити пошук",
    "Search everywhere" : "Шукати всюди",
    "Searching …" : "Пошук ...",
    "Start typing to search" : "Що шукаємо?",
    "No matching results" : "Відсутні збіги",
    "Today" : "Сьогодні",
    "Last 7 days" : "За останні 7 днів",
    "Last 30 days" : "За останні 30 днів",
    "This year" : "Цього року",
    "Last year" : "Минулого року",
    "Unified search" : "Універсальний пошук",
    "Search apps, files, tags, messages" : "Шукати застосунки, файли, мітки, повідомлення",
    "Places" : "Місця",
    "Date" : "Дата",
    "Search people" : "Пошук контактів",
    "People" : "Користувачі",
    "Filter in current view" : "Фільтр поточного подання",
    "Results" : "Результат",
    "Load more results" : "Завантажити більше результатів",
    "Search in" : "Шукати у",
    "Log in" : "Увійти",
    "Logging in …" : "Вхід ...",
    "Log in to {productName}" : "Увійдіть до {productName}",
    "Wrong login or password." : "Неправильне ім'я облікового запису або пароль.",
    "This account is disabled" : "Цей обліковий запис вимкнено.",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ми виявили кілька недійсних спроб входу з вашого IP-адресу. Тому  наступну спробу входу можна буде здійснити через 30 секунд.",
    "Account name or email" : "Ім'я користувача або електронна пошта",
    "Account name" : "Назва облікового запису",
    "Server side authentication failed!" : "Невдала авторизація на стороні сервера!",
    "Please contact your administrator." : "Будь ласка, зверніться до вашого Адміністратора.",
    "Session error" : "Помилка сеансу",
    "It appears your session token has expired, please refresh the page and try again." : "Здається, термін дії вашого токену сеансу закінчився, будь ласка, оновіть сторінку і спробуйте ще раз.",
    "An internal error occurred." : "Виникла внутрішня помилка.",
    "Please try again or contact your administrator." : "Будь ласка, спробуйте ще раз або зверніться до адміністратора.",
    "Password" : "Пароль",
    "Log in with a device" : "Увійти за допомогою пристрою",
    "Login or email" : "Ім'я облікового запису або адреса ел.пошти",
    "Your account is not setup for passwordless login." : "Ваш обліковий запис не налаштовано на безпарольний вхід.",
    "Your connection is not secure" : "Ваше зʼєднання не захищене",
    "Passwordless authentication is only available over a secure connection." : "Авторизація без пароля можлива лише при безпечному з'єднанні.",
    "Browser not supported" : "Оглядач не підтримується",
    "Passwordless authentication is not supported in your browser." : "Ваш браузер не підтримує безпарольний вхід.",
    "Reset password" : "Відновити пароль",
    "Back to login" : "Повернутися на сторінку входу",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "На вашу ел.адресу було надіслано повідомлення про зміну пароля. Якщо ви його не отримали, перевірте адресу ел.пошти, ім'я користувача, скриньку зі спамом або зверніться до адміністратора.",
    "Couldn't send reset email. Please contact your administrator." : "Не вдалося надіслати повідомлення для відновлення пароля. Прохання сконтактувати з адміністратором.",
    "Password cannot be changed. Please contact your administrator." : "Пароль не можна змінити. Будь ласка, зверніться до свого адміністратора.",
    "New password" : "Новий пароль",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Ваші файли зашифровано. У разі перевстановлення паролю ви не зможете отримати доступ до них. Якщо ви не впевнені, що робити, будь ласка, сконтактуйте з адміністратором перед продовженням. Дійсно продовжити?",
    "I know what I'm doing" : "Я знаю що роблю",
    "Resetting password" : "Відновлення пароля",
    "Schedule work & meetings, synced with all your devices." : "Планування роботи та зустрічей із синхронізацією зі всіма вашими пристроями",
    "Keep your colleagues and friends in one place without leaking their private info." : "Створіть спільний безпечний простір для співпраці та обміну даними з вашими колегами та друзями.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Простий застосунок електронної пошти, добре інтегрований з Файлами, Контактами та Календарем.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Обмін повідомленнями в чаті, відеовиклики, надання доступу до екрану, онлайнові зустрічі та вебконференції - все у вашому бравзері та мобільних застосунках.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Спільні документи, електронні таблиці та презентації, створені на Collabora Online.",
    "Distraction free note taking app." : "Застосунок для ведення нотаток без зайвих відволікань.",
    "Recommended apps" : "Рекомендовані застосунки",
    "Loading apps …" : "Завантаження застосунків ...",
    "Could not fetch list of apps from the App Store." : "Не вдалося отримати список застосунків із App Store.",
    "App download or installation failed" : "Помилка із звантаженням або встановленням застосунку",
    "Cannot install this app because it is not compatible" : "Неможливо встановити цей застосунок, оскільки він не є сумісним",
    "Cannot install this app" : "Не вдається встановити цей застосунок",
    "Skip" : "Пропустити",
    "Installing apps …" : "Встановлення застосунків ...",
    "Install recommended apps" : "Встановити рекомендовані застосунки",
    "Avatar of {displayName}" : "Зображення користувача для {displayName}",
    "Settings menu" : "Меню налаштувань",
    "Loading your contacts …" : "Завантаження контактів...",
    "Looking for {term} …" : "Шукаєте {term}",
    "Search contacts" : "Шукати контакти",
    "Reset search" : "Повторити пошук",
    "Search contacts …" : "Пошук контакту...",
    "Could not load your contacts" : "Неможливо завантажити ваші контакти",
    "No contacts found" : "Контактів не знайдено",
    "Show all contacts" : "Показувати всі контакти",
    "Install the Contacts app" : "Встановіть застосунок Контакти",
    "Search" : "Пошук",
    "No results for {query}" : "Немає результатів для {query}",
    "Press Enter to start searching" : "Натисніть Enter, щоб почати пошук",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Для пошуку введіть {minSearchLength} або більше символів","Для пошуку введіть {minSearchLength} або більше символів","Для пошуку введіть {minSearchLength} або більше символів","Для пошуку введіть {minSearchLength} або більше символів"],
    "An error occurred while searching for {type}" : "Завантажити більше результатів",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Пошук здійснюватиметься одразу, як ви почнете набирати. Щоби вибрати результат, будь ласка, скористайтеся кнопками зі стрілками.",
    "Search for {name} only" : "Пошук лише у {name}",
    "Loading more results …" : "Завантаження інших результатів…",
    "Forgot password?" : "Забули пароль?",
    "Back to login form" : "Повернутися на сторінку входу",
    "Back" : "Назад",
    "Login form is disabled." : "Форма входу вимкнена.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Форму авторизації у хмарі Nextcloud вимкнено. Скористайтеся іншим способом входу, якщо є така можливість, або сконтактуйте з адміністратором.",
    "More actions" : "Більше дій",
    "Password is too weak" : "Занадто простий пароль ",
    "Password is weak" : "Простий пароль",
    "Password is average" : "Пароль середньої складності",
    "Password is strong" : "Надійний пароль ",
    "Password is very strong" : "Пароль дуже надійний",
    "Password is extremely strong" : "Надзвичайно надійний пароль",
    "Unknown password strength" : "Невідома ефективність паролю",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Ваш каталог з даними та файли скоріш за все публічно доступні в Інтернеті, оскільки файл <code>.htaccess</code> не налаштовано відповідним чином. ",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Ознайомтеся з{linkStart}документацію{linkEnd} з налаштування сервера.",
    "Autoconfig file detected" : "Виявлено файл автоконфігурації",
    "The setup form below is pre-filled with the values from the config file." : "Форму для налаштування попередньо заповнено значеннями з файлу конфігурації.",
    "Security warning" : "Попередження безпеки",
    "Create administration account" : "Створіть обліковий запис адміністратора",
    "Administration account name" : "Ім'я облікового запису адміністратора",
    "Administration account password" : "Пароль облікового запису адміністратора",
    "Storage & database" : "Сховище і база даних",
    "Data folder" : "Каталог з даними",
    "Database configuration" : "Конфігурація бази даних",
    "Only {firstAndOnlyDatabase} is available." : "Лише {firstAndOnlyDatabase} доступна для вибору.",
    "Install and activate additional PHP modules to choose other database types." : "Встановіть та активуйте додаткові модулі PHP, щоб вибрати інший тип БД.",
    "For more details check out the documentation." : "За подробицями зверніться до документації.",
    "Performance warning" : "Попередження продуктивності",
    "You chose SQLite as database." : "Ви вибрали SQLite як базу даних",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite слід використовувати лише для мінімалістичних серверних конфігурацій або для розробки. Для продуктових версій рекомендуємо використовувати базу даних іншого типу.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Якщо ви використовуєте клієнти для синхронізації файлів, використання SQLite вкрай не рекомендується.",
    "Database user" : "Користувач бази даних",
    "Database password" : "Пароль для бази даних",
    "Database name" : "Назва бази даних",
    "Database tablespace" : "Таблиця бази даних",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Будь ласка, вкажіть номер порту поряд з ім'ям вузла (напр., localhost:5432).",
    "Database host" : "Вузол бази даних",
    "localhost" : "localhost",
    "Installing …" : "Встановлення…",
    "Install" : "Встановити",
    "Need help?" : "Потрібна допомога?",
    "See the documentation" : "Подивитись документацію",
    "{name} version {version} and above" : "{name} версія {version} та вище",
    "This browser is not supported" : "Цей бравзер не підтримується",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш бравзер не підтримується. Будь ласка, оновіть бравзер до новішої версії або скористайтеся таким, що підтримується.",
    "Continue with this unsupported browser" : "Продовжити з бравзером, що не підтримується.",
    "Supported versions" : "Підтримувані версії",
    "Search {types} …" : "Пошук {types} …",
    "Choose {file}" : "Виберіть {file}",
    "Choose" : "Вибрати",
    "Copy to {target}" : "Копіювати до {target}",
    "Copy" : "Копіювати",
    "Move to {target}" : "Перемістити до {target}",
    "Move" : "Перемістити",
    "OK" : "Гаразд",
    "read-only" : "Тільки для читання",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} файловий конфлікт","{count} файлових конфліктів","{count} файлових конфліктів","{count} файлових конфліктів"],
    "One file conflict" : "Один файловий конфлікт",
    "New Files" : "Нові файли",
    "Already existing files" : "Файли що вже існують",
    "Which files do you want to keep?" : "Які файли ви хочете залишити?",
    "If you select both versions, the copied file will have a number added to its name." : "При виборі обох версій, до назви копійованого файлу буде додана цифра",
    "Cancel" : "Скасувати",
    "Continue" : "Продовжити",
    "(all selected)" : "(все вибрано)",
    "({count} selected)" : "({count} вибрано)",
    "Error loading file exists template" : "Помилка при завантаженні шаблону існуючого файлу",
    "Saving …" : "Збереження …",
    "seconds ago" : "кілька секунд тому",
    "Connection to server lost" : "З'єднання з сервером втрачено",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблема під час завантаження сторінки, повторне завантаження за %n секунду.","Проблема під час завантаження сторінки, повторне завантаження за %n секунди.","Проблема під час завантаження сторінки, повторне завантаження за %n секунд.","Проблема під час завантаження сторінки, повторне завантаження за %n секунд."],
    "Add to a project" : "Додати до проєкту",
    "Show details" : "Показати деталі",
    "Hide details" : "Приховати деталі",
    "Rename project" : "Перейменувати проєкт",
    "Failed to rename the project" : "Помилка з перейменуванням проєкту",
    "Failed to create a project" : "Помилка зі створенням проєкту",
    "Failed to add the item to the project" : "Помилка з додаванням елементу до цього проєкту",
    "Connect items to a project to make them easier to find" : "Приєднайте окремі елементи до проєкту для полегшення пошуку",
    "Type to search for existing projects" : "Зазначте для пошуку серед наявних проєктів",
    "New in" : "Нові можливості",
    "View changelog" : "Подивитись зміни",
    "No action available" : "Немає доступних дій",
    "Error fetching contact actions" : "Неможливо отримати дії з контактами",
    "Close \"{dialogTitle}\" dialog" : "Закрити меню \"{dialogTitle}\"",
    "Email length is at max (255)" : "Досягнуто максимальну довжина адреси ел.пошти (255 символів)",
    "Non-existing tag #{tag}" : "Ця мітка не існує #{tag}",
    "Restricted" : "Обмежена",
    "Invisible" : "Невидимка",
    "Delete" : "Вилучити",
    "Rename" : "Перейменувати",
    "Collaborative tags" : "Мітки для організації співпраці",
    "No tags found" : "Міток не знайдено",
    "Clipboard not available, please copy manually" : "Буфер обміну не доступний, скопіюйте вручну",
    "Personal" : "Особисте",
    "Accounts" : "Користувачі",
    "Admin" : "Адміністратор",
    "Help" : "Допомога",
    "Access forbidden" : "Доступ заборонено",
    "Page not found" : "Сторінку не знайдено",
    "The page could not be found on the server or you may not be allowed to view it." : "Не вдалося знайти сторінку на сервері або вам не дозволено її перегляд.",
    "Back to %s" : "Назад до %s",
    "Too many requests" : "Забагато запитів",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Забагато запитів із вашої мережі. Повторіть спробу пізніше або зверніться до адміністратора, якщо це помилка.",
    "Error" : "Помилка",
    "Internal Server Error" : "Внутрішня помилка серверу",
    "The server was unable to complete your request." : "Сервер не зміг обробити ваш запит.",
    "If this happens again, please send the technical details below to the server administrator." : "Якщо це станеться знову, надішліть технічні подробиці адміністратору сервера.",
    "More details can be found in the server log." : "Більше деталей може бути в журналі серверу.",
    "For more details see the documentation ↗." : "Для додаткової інформації дивіться документацію ↗.",
    "Technical details" : "Технічні деталі",
    "Remote Address: %s" : "Віддалена адреса: %s",
    "Request ID: %s" : "ID запиту: %s",
    "Type: %s" : "Тип: %s",
    "Code: %s" : "Код: %s",
    "Message: %s" : "Повідомлення: %s",
    "File: %s" : "Файл: %s",
    "Line: %s" : "Рядок: %s",
    "Trace" : "Трасування",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Схоже, ви намагаєтеся перевстановити Nextcloud. Однак файл CAN_INSTALL відсутній у вашому каталозі конфігурації. Щоб продовжити, створіть файл CAN_INSTALL у папці конфігурації.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Could not remove CAN_INSTALL from the config folder.Please remove this file manually.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Цей застосунок вимагає увімкнений JavaScript для коректної роботи. Будь ласка, активуйте {linkstart}JavaScript{linkend} та оновіть сторінку.",
    "Skip to main content" : "Перейти до основного вмісту",
    "Skip to navigation of app" : "Перейти до навігації застосунку",
    "Go to %s" : "Перейти до %s",
    "Get your own free account" : "Отримати безкоштовний обліковий запис",
    "Connect to your account" : "Увійти до вашого облікового запису",
    "Please log in before granting %1$s access to your %2$s account." : "Для надання %1$s доступу до облікового запису %2$s необхідно увійти в систему.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Якщо ви не намагаєтеся налаштувати новий пристрій або застосунок, то це може означати, що хтось намагається обманом змусити вас надати доступ до ваших даних. У цьому випадку не продовжуйте, а зверніться до системного адміністратора.",
    "App password" : "Пароль застосунку",
    "Grant access" : "Дозволити доступ",
    "Alternative log in using app password" : "Альтернативний логін, використовуючи пароль застосунку",
    "Account access" : "Доступ до облікового запису",
    "Currently logged in as %1$s (%2$s)." : "Зараз увійшли як %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Ви збираєтесь надати %1$s доступ до свого облікового запису %2$s.",
    "Account connected" : "Обліковий запис під’єднано",
    "Your client should now be connected!" : "Зараз ваш клієнт має бути приєднано!",
    "You can close this window." : "Ви можете закрити це вікно.",
    "Previous" : "Назад",
    "This share is password-protected" : "Доступ до цього ресурсу захищений паролем",
    "The password is wrong or expired. Please try again or request a new one." : "Пароль неправильний або термін дії минув. Спробуйте ще раз або надішліть запит на новий.",
    "Please type in your email address to request a temporary password" : "Будь ласка, введіть адресу електронної пошти, щоб отримати тимчасовий пароль",
    "Email address" : "Адреса ел.пошти",
    "Password sent!" : "Пароль надіслано!",
    "You are not authorized to request a password for this share" : "Ви не маєте права запитувати пароль для цього ресурсу",
    "Two-factor authentication" : "Двофакторна авторизація",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Для вашого облікового запису налаштовано посилену безпеку. Виберіть другий фактор авторизації.",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Неможливо завантажити щонайменше один з активованих вами способів двофакторної авторизації. Будь ласка, сконтактуйте з адміністратором.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Двофакторну авторизацію увімкнено, але не налаштовано для вашого облікового запису. Будь ласка, сконтактуйте з вашим адміністратором для отримання допомоги.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Двофакторну авторизацію увімкнено, але не налаштовано для вашого облікового запису. Будь ласка, налаштуйте далі двофакторну авторизацію.",
    "Set up two-factor authentication" : "Налаштувати двофакторну авторизацію",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Двофакторну авторизацію увімкнено, але не налаштовано для вашого облікового запису. Будь ласка, скористайтеся одним з резервних кодів для входу або сконтактуйте з вашим адміністратором для отримання допомоги.",
    "Use backup code" : "Використати резервний код",
    "Cancel login" : "Скасувати вхід",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Двофакторну авторизацію увімкнено для вашого облікового запису. Будь ласка, виберіть провайдера для налаштування:",
    "Error while validating your second factor" : "Помилка під час перевірки вашого другого фактору",
    "Access through untrusted domain" : "Доступ з не довіреного домену",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Будь ласка, зверніться до свого адміністратора. Якщо ви адміністратор, відредагуйте параметр \"trusted_domains\" у config/config.php, як у прикладі у config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Подальшу інформацію з налаштуваннями можна переглянути на сторінці %1$sДокументація%2$s.",
    "App update required" : "Застосунок потребує оновлення",
    "%1$s will be updated to version %2$s" : "%1$s буде оновлено до версії %2$s",
    "The following apps will be updated:" : "Ці застосунки буде оновлено:",
    "These incompatible apps will be disabled:" : "Такі несумісні застосунки буде вимкнено:",
    "The theme %s has been disabled." : "Тему %s було вимкнено.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продовженням переконайтеся, що ви зробили резервну копію бази даних, каталог з конфігурацією та каталоги з даними користувачів.",
    "Start update" : "Почати оновлення",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Щоб уникнути затримок у великих встановленнях, ви можете виконати наступну команду в каталозі встановлення:",
    "Detailed logs" : "Деталізований журнал",
    "Update needed" : "Оновлення необхідно",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Будь ласка, скористайтеся запуском оновлення з командного рядка, оскільки у вас є понад 50 облікових записів.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Щоб отримати допомогу, перегляньте  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацію</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Я знаю, що, якщо я продовжую виконувати оновлення через вебінтерфейс, існує ризик того, що запит завершиться по тайм-ауту, що може призвести до втрати даних, але я маю резервну копію та знаю, як відновити мій сервер у випадку невдачі.",
    "Upgrade via web on my own risk" : "Оновлення через веб-інтерфейс на свій страх і ризик",
    "Maintenance mode" : "Режим технічного обслуговування",
    "This %s instance is currently in maintenance mode, which may take a while." : "Для сервера хмари %s увімкнено режим технічного обслуговування.",
    "This page will refresh itself when the instance is available again." : "Ця сторінка оновиться автоматично, коли сервер знову стане доступний.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Зверніться до вашого системного адміністратора, якщо це повідомлення не зникає або з'явилося несподівано.",
    "Currently open" : "Наразі відкрито",
    "Login with username or email" : "Увійти з ім'ям користувача або ел. поштою",
    "Login with username" : "Увійти з ім'ям користувача",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чати, відеовиклики, демонстрація екану, онлайнові зустрічі та вебконференції у вашому браузері та на мобільних застосунках.",
    "You have not added any info yet" : "Ви ще не додали жодної інформації",
    "{user} has not added any info yet" : "{user} ще не додав жодної інформації",
    "Error opening the user status modal, try hard refreshing the page" : "Помилка відкриття режиму статусу користувача. Спробуйте оновити сторінку",
    "Edit Profile" : "Редагувати профіль",
    "The headline and about sections will show up here" : "Тут відображатимуться заголовок і розділи про",
    "Error loading message template: {error}" : "Помилка при завантаженні шаблону повідомлення: {error}",
    "Very weak password" : "Дуже слабкий пароль",
    "Weak password" : "Слабкий пароль",
    "So-so password" : "Такий собі пароль",
    "Good password" : "Надійний пароль",
    "Strong password" : "Надійний пароль",
    "Profile not found" : "Профіль не знайдено",
    "The profile does not exist." : "Профіль не існує.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш каталог з даними та ваші файли можуть мати доступ з інтернету, оскільки файл .htaccess не дійсний.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Для отримання інформації про те, як правильно налаштувати свій сервер, перегляньте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацію</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Створити адміністративний обліковий запис</strong>",
    "New admin account name" : "Ім'я нового адміністративного облікового запису",
    "New admin password" : "Пароль нового адміністратора",
    "Show password" : "Показати пароль",
    "Toggle password visibility" : "Перемкнути видимість пароля",
    "Configure the database" : "Налаштування бази даних",
    "Only %s is available." : "Доступно тільки %s.",
    "Database account" : "Обліковий запис БД"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
